==> cacheall-0.0.3.tar.gz: cacheall-0.0.3/cacheall/EvictionPolicies/LIFOevictionpolicy.py <==
from Algorithms.doublylinkedlist import DoublyLinkedList as dll 
# LRU cache class
class LIFOCache:

    def __init__(self, capacity,lock):
        # capacity: capacity of cache
        # Initialize all variable
        self.capacity = capacity
        self.map = {}
        self.list=dll()
        self.count = 0
        self.lock=lock


    # This method works in O(1)
    def get(self, key):
        with self.lock:
            if key in self.map:
                node = self.map[key]
                result = node.val
                print('Got the value : {} for the key: {}'.format(result, key))
                return result
            print('Did not get any value for the key: {}'.format(key))
            self.list.printlist()
        return -1

    # This method works in O(1)
    def set(self, key, value):
        with self.lock:
            print('going to set the (key, value) : ( {}, {})'.format(key, value))
            if key in self.map:
                node = self.map[key]
                node.val = value
            else:
                if self.count < self.capacity:
                    
                    self.count += 1
                    self.map[key]=self.list.addToHead(key,value)
                    # print(self.count)
                else:
                    # print(self.list.tail.key)
                    del self.map[self.list.head.key]
                    self.list.deleteNode(self.list.head)
                    self.map[key]=self.list.addToHead(key,value)
        
            self.list.printlist()

==> cacheall-0.0.9.tar.gz: cacheall-0.0.9/cacheall/EvictionPolicies/LIFOevictionpolicy.py <==
from cacheall.Algorithms.doublylinkedlist import DoublyLinkedList as dll 
# LRU cache class
class LIFOCache:

    def __init__(self, capacity,lock):
        # capacity: capacity of cache
        # Initialize all variable
        self.capacity = capacity
        self.map = {}
        self.list=dll()
        self.count = 0
        self.lock=lock


    # This method works in O(1)
    def get(self, key):
        with self.lock:
            if key in self.map:
                node = self.map[key]
                result = node.val
                print('Got the value : {} for the key: {}'.format(result, key))
                return result
            print('Did not get any value for the key: {}'.format(key))
            self.list.printlist()
        return -1

    # This method works in O(1)
    def set(self, key, value):
        with self.lock:
            print('going to set the (key, value) : ( {}, {})'.format(key, value))
            if key in self.map:
                node = self.map[key]
                node.val = value
            else:
                if self.count < self.capacity:
                    
                    self.count += 1
                    self.map[key]=self.list.addToHead(key,value)
                    # print(self.count)
                else:
                    # print(self.list.tail.key)
                    del self.map[self.list.head.key]
                    self.list.deleteNode(self.list.head)
                    self.map[key]=self.list.addToHead(key,value)
        
            self.list.printlist()
